@@ -35,10 +35,11 @@ DirectoryEntry::DirectoryEntry(const dirent *d) :
 		linkType = 0;		// Ignore
 		type = 0;
 	}
-	else				// Get actual type if DT_UNKNOWN
+	else {				// Get actual type if DT_UNKNOWN
 					// Get timestamp if DT_DIR
 					// Get link destination if DT_LNK
-		Init();
+	 	Init();
+	}
 #else
 	Init();
 #endif
