@@ -24,7 +24,7 @@
 #include "config.h"
 #include <string>
 
-USING_NAMESPACE_STD
+USING_NAMESPACE_STD;
 
 string	ExpandDirectory(const string &src, int quote = 0);
 
