@@ -27,7 +27,7 @@
 #include CXX__HEADER_cstring
 #include "buffer.h"
 
-USING_NAMESPACE_STD
+USING_NAMESPACE_STD;
 
 /*************************************************************************
 	Program return codes
@@ -62,7 +62,7 @@ class ErrorGeneric : public ErrorBase {
 	public:
 		ErrorGeneric(const char *msg);
 		ErrorGeneric(Buffer &buf);
-		ErrorGeneric(ostrstream &buf);
+		ErrorGeneric(gtstream &buf);
 		template <class T1> ErrorGeneric(const char *msg, T1 t1);
 		template <class T1, class T2> ErrorGeneric(const char *msg, T1 t1, T2 t2);
 
@@ -71,20 +71,16 @@ class ErrorGeneric : public ErrorBase {
 
 template <class T1> ErrorGeneric::ErrorGeneric(const char *msg, T1 t1)
 {
-	ostrstream buf;
+	gtstream buf;
 	gtout(buf, msg) << t1;
-	buf << ends;
 	str = buf.str();
-	buf.freeze(false);
 }
 
 template <class T1, class T2> ErrorGeneric::ErrorGeneric(const char *msg, T1 t1, T2 t2)
 {
-	ostrstream buf;
+	gtstream buf;
 	gtout(buf, msg) << t1 << t2;
-	buf << ends;
 	str = buf.str();
-	buf.freeze(false);
 }
 
 
@@ -92,7 +88,7 @@ class ErrorGenericSyntax : public ErrorGeneric {
 	public:
 		ErrorGenericSyntax(const char *msg) :  ErrorGeneric(msg) {}
 		ErrorGenericSyntax(Buffer &buf) : ErrorGeneric(buf) {}
-		ErrorGenericSyntax(ostrstream &buf) : ErrorGeneric(buf) {}
+		ErrorGenericSyntax(gtstream &buf) : ErrorGeneric(buf) {}
 		template <class T1> ErrorGenericSyntax(const char *msg, T1 t1)
 						: ErrorGeneric(msg, t1) {}
 		template <class T1, class T2> ErrorGenericSyntax(const char *msg, T1 t1, T2 t2)
@@ -105,7 +101,7 @@ class ErrorGenericCommandLine : public ErrorGeneric {
 	public:
 		ErrorGenericCommandLine(const char *msg) :  ErrorGeneric(msg) {}
 		ErrorGenericCommandLine(Buffer &buf) : ErrorGeneric(buf) {}
-		ErrorGenericCommandLine(ostrstream &buf) : ErrorGeneric(buf) {}
+		ErrorGenericCommandLine(gtstream &buf) : ErrorGeneric(buf) {}
 		template <class T1> ErrorGenericCommandLine(const char *msg, T1 t1)
 						: ErrorGeneric(msg, t1) {}
 		template <class T1, class T2> ErrorGenericCommandLine(const char *msg, T1 t1, T2 t2)
@@ -118,7 +114,7 @@ class ErrorGenericFile : public ErrorGeneric {
 	public:
 		ErrorGenericFile(const char *msg) :  ErrorGeneric(msg) {}
 		ErrorGenericFile(Buffer &buf) : ErrorGeneric(buf) {}
-		ErrorGenericFile(ostrstream &buf) : ErrorGeneric(buf) {}
+		ErrorGenericFile(gtstream &buf) : ErrorGeneric(buf) {}
 		template <class T1> ErrorGenericFile(const char *msg, T1 t1)
 						: ErrorGeneric(msg, t1) {}
 		template <class T1, class T2> ErrorGenericFile(const char *msg, T1 t1, T2 t2)
