@@ -35,7 +35,7 @@ extern "C" {
 
 #include "buffer.h"
 
-USING_NAMESPACE_STD
+USING_NAMESPACE_STD;
 
 gzFile	gzopen(const string &path, const char *mode);
 
