@@ -99,6 +99,7 @@ void	Help()
 		  "     --features     Display features included during compilation\n"
 		  "     -h, --help     Display this help\n"
 		  "     --helpinst     Display help about shell alias/function installation\n");
+	cout << _("     -p NAME        Use configuration profile NAME\n");
 	cout << _("     -r             Rescan directory tree\n"
 		  "     -rf            Rescan directory tree using full rescan mode\n"
 		  "     -rp DIR        Rescan part of directory tree beginning at DIR\n"
@@ -194,6 +195,22 @@ void	InitNewDir()
 	Main
 *************************************************************************/
 
+string	home_dir;
+
+void	SetSaveFile()
+{
+					// Initialize ~/.kcd.save.gz,
+	if (getenv("KCD_DIRTREE") && strlen(getenv("KCD_DIRTREE"))) {
+		saveFile = getenv("KCD_DIRTREE");
+	}
+	else {
+		saveFile = home_dir;
+		saveFile += ".kcd.save.";
+		saveFile += GetCurrentProfile();
+		saveFile += ".gz";	// Add appropriate filename
+	}
+}
+
 void	mainReal(int argc, char *argv[])
 {
 #ifdef HAVE_SETENV
@@ -212,23 +229,16 @@ void	mainReal(int argc, char *argv[])
 	textdomain(PACKAGE);
 #endif
 
+	SetCurrentProfile("kcd");
+
 					// Save current working dir
 	saveCwd = k_getcwd();
-					// Initialize ~/.kcd.save.gz,
-					// ~/.kcd.newdir and
+					// Initialize ~/.kcd.newdir and
 					// ~/.kcd.conf filename
-	string	home_dir = ExpandDirectory("~");
+	home_dir = ExpandDirectory("~");
 	if (home_dir[home_dir.size()-1] != '/')	// Not end with "/"
 		home_dir += '/';	// Need to add a "/" after home dir
 
-	if (getenv("KCD_DIRTREE") && strlen(getenv("KCD_DIRTREE"))) {
-		saveFile = getenv("KCD_DIRTREE");
-	}
-	else {
-		saveFile = home_dir;
-		saveFile += ".kcd.save.gz";	// Add appropriate filename
-	}
-
 	if (getenv("KCD_TEMP") && strlen(getenv("KCD_TEMP"))) {
 		dirFile = getenv("KCD_TEMP");
 	}
@@ -296,22 +306,38 @@ void	mainReal(int argc, char *argv[])
 				return;
 			}
 			else if (strcmp(argv[argcCur], "-ia") == 0) {
-				if (argcLeft == 1)
-					cout << "alias kcd=\'. /usr/bin/kcdscr\'\n";
+				LoadAllConfig(true);
+				if (argcLeft == 1) {
+					for (configMap::iterator i = allConfig.begin(); i != allConfig.end(); ++i) {
+						if ((*i).first != "*")
+							cout << "alias " << (*i).first << "=\'. /usr/bin/kcdscr -p "
+							     << (*i).first << "\';\n";
+					}
+				}
 				else
 					throw ErrorGenericCommandLine(_("argument not allowed for `-ia\'"));
 				return;
 			}
 			else if (strcmp(argv[argcCur], "-ic") == 0) {
+				LoadAllConfig(true);
 				if (argcLeft == 1)
-					cout << "alias kcd \'source /usr/bin/kcdscr\'\n";
+					for (configMap::iterator i = allConfig.begin(); i != allConfig.end(); ++i) {
+						if ((*i).first != "*")
+						cout << "alias " << (*i).first << " \'source /usr/bin/kcdscr -p "
+						     << (*i).first << "\';\n";
+					}
 				else
 					throw ErrorGenericCommandLine(_("argument not allowed for `-ic\'"));
 				return;
 			}
 			else if (strcmp(argv[argcCur], "-if") == 0) {
+				LoadAllConfig(true);
 				if (argcLeft == 1)
-					cout << "kcd () { . /usr/bin/kcdscr \"$@\" ; }\n";
+					for (configMap::iterator i = allConfig.begin(); i != allConfig.end(); ++i) {
+						if ((*i).first != "*")
+						cout << (*i).first << " () { . /usr/bin/kcdscr -p "
+						     << (*i).first << " \"$@\" ; };\n";
+					}
 				else
 					throw ErrorGenericCommandLine(_("argument not allowed for `-if\'"));
 				return;
@@ -328,25 +354,50 @@ void	mainReal(int argc, char *argv[])
 				return;
 			}
 			else if (strcmp(argv[argcCur], "-ias") == 0) {
+				LoadAllConfig(true);
 				if (argcLeft == 2)
-					cout << "alias kcd=\'. " << argv[argcCur+1] << "/kcdscr\'\n";
+					for (configMap::iterator i = allConfig.begin(); i != allConfig.end(); ++i) {
+						if ((*i).first != "*")
+						cout << "alias " << (*i).first << "=\'. " << argv[argcCur+1] << "/kcdscr -p "
+						     << (*i).first << "\';\n";
+					}
 				else
 					throw ErrorGenericCommandLine(_("one argument required for `-ias\'"));
 				return;
 			}
 			else if (strcmp(argv[argcCur], "-ics") == 0) {
+				LoadAllConfig(true);
 				if (argcLeft == 2)
-					cout << "alias kcd \'source " << argv[argcCur+1] << "/kcdscr\'\n";
+					for (configMap::iterator i = allConfig.begin(); i != allConfig.end(); ++i) {
+						if ((*i).first != "*")
+						cout << "alias " << (*i).first << " \'source " << argv[argcCur+1] << "/kcdscr -p "
+						     << (*i).first << "\';\n";
+					}
 				else
 					throw ErrorGenericCommandLine(_("one argument required for `-ics\'"));
 				return;
 			}
 			else if (strcmp(argv[argcCur], "-ifs") == 0) {
+				LoadAllConfig(true);
 				if (argcLeft == 2)
-					cout << "kcd () { . " << argv[argcCur+1] << "/kcdscr \"$@\" ; }\n";
+					for (configMap::iterator i = allConfig.begin(); i != allConfig.end(); ++i) {
+						if ((*i).first != "*")
+						cout << (*i).first << " () { . " << argv[argcCur+1] << "/kcdscr -p "
+						     << (*i).first << " \"$@\" ; };\n";
+					}
 				else
 					throw ErrorGenericCommandLine(_("one argument required for `-ifs\'"));
 				return;
+			}
+						// Profile
+			else if (strcmp(argv[argcCur], "-p") == 0) {
+				if (argcLeft >= 2)
+					SetCurrentProfile(argv[argcCur+1]);
+				else
+					throw ErrorGenericCommandLine(_("one argument required for `-p\'"));
+						// Consume argument of -rp
+				argcCur++;
+				argcLeft--;
 			}
 						// Rescan dir.
 			else if (strncmp(argv[argcCur], "-r", 2) == 0) {
@@ -394,6 +445,8 @@ void	mainReal(int argc, char *argv[])
 				throw ErrorGenericCommandLine(_("unknown option"));
 			}
 			else {				// Not an option, must be a directory name
+				SetSaveFile();
+
 				if (argcLeft == 1 && rescan == 0)
 					CD(argv[argcCur]);
 				else			// Too many arguments
@@ -406,6 +459,8 @@ void	mainReal(int argc, char *argv[])
 		}
 
 		if (rescan) {
+			SetSaveFile();
+
 			if (partial_dir.size())
 				PartialScanDir(partial_dir, forceFullScan);
 			else
@@ -413,6 +468,8 @@ void	mainReal(int argc, char *argv[])
 		}
 		else {					// Consumed all option but
 							// no action specified yet
+			SetSaveFile();
+
 			CD("");
 		}
 	}
