@@ -25,7 +25,7 @@
 #include "setupcurses.h"
 #include "cxxlib.h"
 
-USING_NAMESPACE_STD
+USING_NAMESPACE_STD;
 
 /*************************************************************************
 	ACS fallback support
